@@ -3,12 +3,10 @@ Built-in block-level token classes.
 """
 
 import re
-import sys
 from itertools import zip_longest
 import mistletoe.block_tokenizer as tokenizer
-from mistletoe import span_token
+from mistletoe import token, span_token
 from mistletoe.core_tokens import (
-        is_link_label,
         follows,
         shift_whitespace,
         whitespace,
@@ -80,7 +78,7 @@ def reset_tokens():
     _token_types = [globals()[cls_name] for cls_name in __all__]
 
 
-class BlockToken(object):
+class BlockToken(token.Token):
     """
     Base class for block-level tokens. Recursively parse inner tokens.
 
@@ -138,6 +136,7 @@ class BlockToken(object):
 class Document(BlockToken):
     """
     Document token.
+    This is a container block token. Its children are block tokens - container or leaf ones.
     """
     def __init__(self, lines):
         if isinstance(lines, str):
@@ -154,16 +153,18 @@ class Document(BlockToken):
 
 class Heading(BlockToken):
     """
-    Heading token. (["### some heading ###\\n"])
-    Boundary between span-level and block-level tokens.
+    ATX heading token. (["### some heading ###\\n"])
+    This is a leaf block token. Its children are inline (span) tokens.
 
     Attributes:
         level (int): heading level.
         children (list): inner tokens.
     """
+    repr_attributes = ("level",)
     pattern = re.compile(r' {0,3}(#{1,6})(?:\n|\s+?(.*?)(?:\n|\s+?#+\s*?$))')
     level = 0
     content = ''
+
     def __init__(self, match):
         self.level, content = match
         super().__init__(content, span_token.tokenize_inner)
@@ -186,10 +187,15 @@ class Heading(BlockToken):
 
 class SetextHeading(BlockToken):
     """
-    Setext headings.
-    
+    Setext heading token.
+    This is a leaf block token. Its children are inline (span) tokens.
+
     Not included in the parsing process, but called by Paragraph.__new__.
+
+    Attributes:
+        level (int): heading level.
     """
+    repr_attributes = ("level",)
     def __init__(self, lines):
         self.level = 1 if lines.pop().lstrip().startswith('=') else 2
         content = '\n'.join([line.strip() for line in lines])
@@ -206,7 +212,8 @@ class SetextHeading(BlockToken):
 
 class Quote(BlockToken):
     """
-    Quote token. (["> # heading\\n", "> paragraph\\n"])
+    Block quote token. (["> # heading\\n", "> paragraph\\n"])
+    This is a container block token. Its children are block tokens - container or leaf ones.
     """
     def __init__(self, parse_buffer):
         # span-level tokenizing happens here.
@@ -287,7 +294,7 @@ class Quote(BlockToken):
 class Paragraph(BlockToken):
     """
     Paragraph token. (["some\\n", "continuous\\n", "lines\\n"])
-    Boundary between span-level and block-level tokens.
+    This is a leaf block token. Its children are inline (span) tokens.
     """
     setext_pattern = re.compile(r' {0,3}(=|-)+ *$')
     parse_setext = True  # can be disabled by Quote
@@ -353,12 +360,14 @@ class Paragraph(BlockToken):
 
 class BlockCode(BlockToken):
     """
-    Indented code.
+    Indented code block token.
+    This is a leaf block token with a single child of type span_token.RawText.
 
     Attributes:
         children (list): contains a single span_token.RawText token.
         language (str): always the empty string.
     """
+    repr_attributes = ("language",)
     def __init__(self, lines):
         self.language = ''
         self.children = (span_token.RawText(''.join(lines).strip('\n')+'\n'),)
@@ -397,13 +406,14 @@ class BlockCode(BlockToken):
 
 class CodeFence(BlockToken):
     """
-    Code fence. (["```sh\\n", "rm -rf /", ..., "```"])
-    Boundary between span-level and block-level tokens.
+    Fenced code block token. (["```sh\\n", "rm -rf /", ..., "```"])
+    This is a leaf block token with a single child of type span_token.RawText.
 
     Attributes:
         children (list): contains a single span_token.RawText token.
         language (str): language of code block (default to empty).
     """
+    repr_attributes = ("language",)
     pattern = re.compile(r'( {0,3})(`{3,}|~{3,}) *(\S*)')
     _open_info = None
     def __init__(self, match):
@@ -442,12 +452,14 @@ class CodeFence(BlockToken):
 class List(BlockToken):
     """
     List token.
+    This is a container block token. Its children are list item tokens.
 
     Attributes:
         children (list): a list of ListItem tokens.
         loose (bool): whether the list is loose.
         start (NoneType or int): None if unordered, starting number if ordered.
     """
+    repr_attributes = ("loose", "start")
     pattern = re.compile(r' {0,3}(?:\d{0,9}[.)]|[+\-*])(?:[ \t]*$|[ \t]+)')
     def __init__(self, matches):
         self.children = [ListItem(*match) for match in matches]
@@ -494,9 +506,12 @@ class List(BlockToken):
 
 class ListItem(BlockToken):
     """
-    List items. Not included in the parsing process, but called by List.
-    """
+    List item token.
+    This is a container block token. Its children are block tokens - container or leaf ones.
 
+    Not included in the parsing process, but called by List.
+    """
+    repr_attributes = ("leader", "prepend", "loose")
     pattern = re.compile(r'\s*(\d{0,9}[.)]|[+\-*])(\s*$|\s+)')
 
     def __init__(self, parse_buffer, prepend, leader):
@@ -613,12 +628,14 @@ class ListItem(BlockToken):
 class Table(BlockToken):
     """
     Table token.
+    This is a container block token. Its children are table row tokens.
 
     Attributes:
         has_header (bool): whether table has header row.
         column_align (list): align options for each column (default to [None]).
         children (list): inner tokens (TableRows).
     """
+    repr_attributes = ("column_align",)
     def __init__(self, lines):
         if '---' in lines[1]:
             self.column_align = [self.parse_align(column)
@@ -673,9 +690,11 @@ class Table(BlockToken):
 class TableRow(BlockToken):
     """
     Table row token. Supports escaped pipes in table cells (for primary use within code spans).
+    This is a container block token. Its children are table cell tokens.
 
     Should only be called by Table.__init__().
     """
+    repr_attributes = ("row_align",)
     # Note: Python regex requires fixed-length look-behind,
     # so we cannot use a more precise alternative: r"(?<!\\(?:\\\\)*)(\|)"
     split_pattern = re.compile(r"(?<!\\)\|")
@@ -691,7 +710,7 @@ class TableRow(BlockToken):
 class TableCell(BlockToken):
     """
     Table cell token.
-    Boundary between span-level and block-level tokens.
+    This is a leaf block token. Its children are inline (span) tokens.
 
     Should only be called by TableRow.__init__().
 
@@ -699,6 +718,7 @@ class TableCell(BlockToken):
         align (bool): align option for current cell (default to None).
         children (list): inner (span-)tokens.
     """
+    repr_attributes = ("align",)
     def __init__(self, content, align=None):
         self.align = align
         super().__init__(content, span_token.tokenize_inner)
@@ -707,6 +727,7 @@ class TableCell(BlockToken):
 class Footnote(BlockToken):
     """
     Footnote token. A "link reference definition" according to the spec.
+    This is a leaf block token. Its children are inline (span) tokens.
 
     The constructor returns None, because the footnote information
     is stored in Footnote.read.
@@ -885,6 +906,7 @@ class Footnote(BlockToken):
 class ThematicBreak(BlockToken):
     """
     Thematic break token (a.k.a. horizontal rule.)
+    This is a leaf block token without children.
     """
     pattern = re.compile(r' {0,3}(?:([-_*])\s*?)(?:\1\s*?){2,}$')
     def __init__(self, _):
@@ -901,10 +923,11 @@ class ThematicBreak(BlockToken):
 
 class HTMLBlock(BlockToken):
     """
-    Block-level HTML tokens.
+    Block-level HTML token.
+    This is a leaf block token without children.
 
     Attributes:
-        content (str): literal strings rendered as-is.
+        content (str): the raw HTML content.
     """
     _end_cond = None
     multiblock = re.compile(r'<(script|pre|style)[ >\n]')
